@@ -12,7 +12,8 @@ SPVM_ENV_PRECOMPILE* SPVM_API_PRECOMPILE_new_env() {
     SPVM_API_PRECOMPILE_free_precompile,
     SPVM_API_PRECOMPILE_set_runtime,
     SPVM_API_PRECOMPILE_get_runtime,
-    SPVM_API_PRECOMPILE_create_precompile_source,
+    SPVM_API_PRECOMPILE_build_class_source,
+    SPVM_API_PRECOMPILE_build_method_source,
   };
   SPVM_ENV_PRECOMPILE* env_precompile = calloc(1, sizeof(env_precompile_init));
   memcpy(env_precompile, env_precompile_init, sizeof(env_precompile_init));
@@ -37,6 +38,10 @@ SPVM_RUNTIME* SPVM_API_PRECOMPILE_get_runtime(SPVM_PRECOMPILE* precompile) {
   return SPVM_PRECOMPILE_get_runtime(precompile);
 }
 
-void SPVM_API_PRECOMPILE_create_precompile_source(SPVM_PRECOMPILE* precompile, SPVM_STRING_BUFFER* string_buffer, const char* class_name) {
-  SPVM_PRECOMPILE_create_precompile_source(precompile, string_buffer, class_name);
+void SPVM_API_PRECOMPILE_build_class_source(SPVM_PRECOMPILE* precompile, SPVM_STRING_BUFFER* string_buffer, const char* class_name) {
+  SPVM_PRECOMPILE_build_class_source(precompile, string_buffer, class_name);
+}
+
+void SPVM_API_PRECOMPILE_build_method_source(SPVM_PRECOMPILE* precompile, SPVM_STRING_BUFFER* string_buffer, const char* class_name, const char* method_name) {
+  SPVM_PRECOMPILE_build_method_source(precompile, string_buffer, class_name, method_name);
 }
