@@ -7,11 +7,13 @@
 const char* const* SPVM_ATTRIBUTE_C_ID_NAMES(void) {
 
   static const char* const id_names[] = {
+    "unknown",
     "mulnum_t",
     "pointer_t",
     "native",
     "precompile",
     "public",
+    "protected",
     "private",
     "rw",
     "ro",
